==> graveman_0.3.10-2.orig.tar.gz: graveman-0.3.10/include/callbacks.h <==
/* callback.h
 * Copyright (C) 2005 Sylvain Cresto <scresto@gmail.com>
 *
 * This file is part of graveman!
 *
 * graveman! is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 * 
 * graveman! is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA. 
 * 
 * URL: http://www.nongnu.org/graveman/
 *
 */

#ifndef _G_CALLBACKS_H
#define _G_CALLBACKS_H

extern void gtk_devices_edit(GtkWidget *Abtn, gpointer Adata);
extern void gtk_devices_remove(GtkWidget *Abtn, gpointer Adata);
extern void gtk_devices_add(GtkWidget *Abtn, gpointer Adata);
extern gboolean encours_callback(gpointer Adata);
extern void on_about (GtkMenuItem *Amenuitem, gpointer Adata);
extern gboolean on_closeabout (GtkWidget *Awidget, GdkEventButton *Aevent, gpointer Adata);
extern void on_selectgraveur(GtkWidget *Acombo, gpointer Adata);
extern void gtk_file_sel(GtkWidget *Abtn, gpointer Adata);
extern void confirm_erasecdrw (GtkWidget *Abtn, gpointer Adata);
extern void confirm_fixcd (GtkWidget *Abtn, gpointer Adata);
extern void confirm_burn (GtkWidget *Abtn, gpointer Adata);
extern gboolean abort_gravure (GtkWidget *Abtn, gpointer Adata);
extern void gtk_data_addfile(GtkWidget *Abtn, gpointer Adata);
extern void gtk_data_adddirectory(GtkWidget *Abtn, gpointer Adata);
extern void gtk_data_removefiles(GtkWidget *Abtn, gpointer Adata);
extern void gtk_audio_removetrack(GtkWidget *Abtn, gpointer Adata);
extern gboolean gtk_do_eventlisteajoutfichiers(GtkWidget *Lliste, GdkEventButton *AEvent);
extern void gtk_data_renommerelement(GtkWidget *btn, gpointer Adata);
extern void gtk_data_creerrepertoire(GtkWidget *btn, gpointer Adata);
extern void gtk_audio_addtrack(GtkWidget *btn, gpointer Adata);
extern void gtk_data_expandelement(GtkWidget *btn, gpointer Adata);
extern void gonextpage(GtkWidget *Abtn, GtkNotebook *Anotebook);
extern void text_buffer_callback(GtkTextBuffer *Aobj, gpointer Adata);
extern void menu_active_panel(GtkWidget *Amenuitem, gpointer Adata);
extern void gtk_combotext_changed(GtkWidget *Acombo, gpointer Adata);
extern void switchpage(GtkNotebook *Anotebook, GtkNotebookPage *Anotebookpage, guint Apagenum, gpointer Adata);
extern void menu_active_proprietes(GtkWidget *Amenuitem, gpointer Adata);
extern void cherchelecteur(GtkWidget *Aobj, gpointer data);
extern void chercheprog(GtkWidget *Aobj, gpointer data);
extern void abort_encours(GtkWidget *Abtn, gpointer Adata);
extern void menu_quit(GtkWidget *Aobj1, gpointer Adata);
extern void delete_event_quit(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
extern void delete_event_encours(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
extern void view_popupmenu_addaudio(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern void key_popupmenu_addaudio(GtkWidget *Aliste, gpointer Adata);
extern void view_popupmenu_addfile(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern void key_popupmenu_addfile(GtkWidget *Aliste, gpointer Adata);
extern void view_popupmenu_devices(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern void key_popupmenu_devices(GtkWidget *Aliste, gpointer Adata);
extern void view_popupmenu_charset(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern void key_popupmenu_charset(GtkWidget *Aliste, gpointer Adata);
extern void view_popupmenu_display(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern void key_popupmenu_display(GtkWidget *Aliste, gpointer Adata);
extern void change_remplissage(GtkWidget *Acombo, gpointer Adata);
extern gboolean on_select_files (GtkTreeSelection *Aselection, GtkTreeModel *Amodel,
                       GtkTreePath *Apath, gboolean Apath_currently_selected, gpointer Adata);
extern void audio_dnd_data_received (GtkWidget *Aliste, GdkDragContext *Acontext, gint Ax, gint Ay, GtkSelectionData *Aseldata, guint Ainfo, guint Atime, gpointer Adata);
extern void data_dnd_data_received (GtkWidget *Aliste, GdkDragContext *Acontext, gint Ax, gint Ay, GtkSelectionData *Aseldata, guint Ainfo, guint Atime, gpointer Adata);
extern void menu_load(GtkMenuItem *Amenuitem, gpointer Adata);
extern void menu_start_new(GtkMenuItem *Amenuitem, gpointer Adata);
extern void on_addmediaformat(GtkWidget *Abtn, gpointer Adata);
extern void update_media_unit(GtkWidget *Acombo, gpointer Adata);
extern gboolean update_media_fields(GtkWidget *Awidget, gpointer Adata);
extern void gtk_def_imageboot(GtkWidget *Abtn, gpointer Adata);
extern gboolean quit_property(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
extern gboolean on_deleteevent_gravure(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
extern void gtk_display_switchstatusbar(GtkWidget *Abtn, gpointer Adata);
extern void gtk_display_updatesize(GtkWidget *Abtn, gpointer Adata);
extern void popup_formatdvdrw(GtkWidget *Abtn, gpointer Adata);
extern void gtk_confirm_dvdoperation(GtkWidget *Abtn, gpointer Adata);
extern void change_datamulti(GtkWidget *Amulti, gpointer Adata);
extern void _add_a_piste(gchar *Anom, GtkListStore *Aliststore, Tgrave *Ag);
extern gboolean gtk_do_eventbuttonpress(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern gboolean gtk_do_eventkeyrelease(GtkWidget *Aliste, GdkEventKey *Aevent, gpointer Adata);

#endif

/*
 * vim:et:ts=8:sts=2:sw=2
 */

==> graveman-0.3.12-5.tar.gz: graveman-0.3.12-5/include/callbacks.h <==
/* callback.h
 * Copyright (C) 2005 Sylvain Cresto <scresto@gmail.com>
 *
 * This file is part of graveman!
 *
 * graveman! is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or
 * (at your option) any later version.
 * 
 * graveman! is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA. 
 * 
 * URL: http://www.nongnu.org/graveman/
 *
 */

#ifndef _G_CALLBACKS_H
#define _G_CALLBACKS_H

extern void gtk_devices_edit(GtkWidget *Abtn, gpointer Adata);
extern void gtk_devices_remove(GtkWidget *Abtn, gpointer Adata);
extern void gtk_devices_add(GtkWidget *Abtn, gpointer Adata);
extern gboolean encours_callback(gpointer Adata);
extern void on_about (GtkMenuItem *Amenuitem, gpointer Adata);
extern gboolean on_closeabout (GtkWidget *Awidget, GdkEventButton *Aevent, gpointer Adata);
extern void on_selectgraveur(GtkWidget *Acombo, gpointer Adata);
extern void gtk_file_sel(GtkWidget *Abtn, gpointer Adata);
extern void confirm_erasecdrw (GtkWidget *Abtn, gpointer Adata);
extern void confirm_fixcd (GtkWidget *Abtn, gpointer Adata);
extern void confirm_burn (GtkWidget *Abtn, gpointer Adata);
extern gboolean abort_gravure (GtkWidget *Abtn, gpointer Adata);
extern void gtk_data_addfile(GtkWidget *Abtn, gpointer Adata);
extern void gtk_data_adddirectory(GtkWidget *Abtn, gpointer Adata);
extern void gtk_data_removefiles(GtkWidget *Abtn, gpointer Adata);
extern void gtk_audio_removetrack(GtkWidget *Abtn, gpointer Adata);
extern gboolean gtk_do_eventlisteajoutfichiers(GtkWidget *Lliste, GdkEventButton *AEvent);
extern void callbacks_data_renameitem(GtkWidget *btn, gpointer Adata);
extern void gtk_data_creerrepertoire(GtkWidget *btn, gpointer Adata);
extern void gtk_audio_addtrack(GtkWidget *btn, gpointer Adata);
extern void gtk_data_expandelement(GtkWidget *Abtn, gpointer Adata);
extern void gonextpage(GtkWidget *Abtn, GtkNotebook *Anotebook);
extern void text_buffer_callback(GtkTextBuffer *Aobj, gpointer Adata);
extern void menu_active_panel(GtkWidget *Amenuitem, gpointer Adata);
extern void gtk_combotext_changed(GtkWidget *Acombo, gpointer Adata);
extern void switchpage(GtkNotebook *Anotebook, GtkNotebookPage *Anotebookpage, guint Apagenum, gpointer Adata);
extern void menu_active_proprietes(GtkWidget *Amenuitem, gpointer Adata);
extern void cherchelecteur(GtkWidget *Aobj, gpointer data);
extern void chercheprog(GtkWidget *Aobj, gpointer data);
extern void abort_encours(GtkWidget *Abtn, gpointer Adata);
extern void menu_quit(GtkWidget *Aobj1, gpointer Adata);
extern void delete_event_quit(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
extern void delete_event_encours(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
extern void view_popupmenu_addaudio(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern void key_popupmenu_addaudio(GtkWidget *Aliste, gpointer Adata);
extern void view_popupmenu_addfile(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern void key_popupmenu_addfile(GtkWidget *Aliste, gpointer Adata);
extern void view_popupmenu_devices(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern void key_popupmenu_devices(GtkWidget *Aliste, gpointer Adata);
extern void view_popupmenu_charset(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern void key_popupmenu_charset(GtkWidget *Aliste, gpointer Adata);
extern void view_popupmenu_display(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern void key_popupmenu_display(GtkWidget *Aliste, gpointer Adata);
extern void change_remplissage(GtkWidget *Acombo, gpointer Adata);
extern gboolean on_select_files (GtkTreeSelection *Aselection, GtkTreeModel *Amodel,
                       GtkTreePath *Apath, gboolean Apath_currently_selected, gpointer Adata);
extern void audio_dnd_data_received (GtkWidget *Aliste, GdkDragContext *Acontext, gint Ax, gint Ay, GtkSelectionData *Aseldata, guint Ainfo, guint Atime, gpointer Adata);
extern void data_dnd_data_received (GtkWidget *Aliste, GdkDragContext *Acontext, gint Ax, gint Ay, GtkSelectionData *Aseldata, guint Ainfo, guint Atime, gpointer Adata);
extern void menu_load(GtkMenuItem *Amenuitem, gpointer Adata);
extern void menu_start_new(GtkMenuItem *Amenuitem, gpointer Adata);
extern void on_addmediaformat(GtkWidget *Abtn, gpointer Adata);
extern void update_media_unit(GtkWidget *Acombo, gpointer Adata);
extern gboolean update_media_fields(GtkWidget *Awidget, gpointer Adata);
extern void gtk_def_imageboot(GtkWidget *Abtn, gpointer Adata);
extern gboolean quit_property(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
extern gboolean on_deleteevent_gravure(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
extern void gtk_display_switchstatusbar(GtkWidget *Abtn, gpointer Adata);
extern void gtk_display_updatesize(GtkWidget *Abtn, gpointer Adata);
extern void popup_formatdvdrw(GtkWidget *Abtn, gpointer Adata);
extern void gtk_confirm_dvdoperation(GtkWidget *Abtn, gpointer Adata);
extern void change_datamulti(GtkWidget *Amulti, gpointer Adata);
extern void _add_a_piste(gchar *Anom, GtkListStore *Aliststore, Tgrave *Ag);
extern gboolean gtk_do_eventbuttonpress(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
extern gboolean gtk_do_eventkeyrelease(GtkWidget *Aliste, GdkEventKey *Aevent, gpointer Adata);
extern void callbacks_data_asksort(GtkWidget *Abtn, gpointer Adata);
extern gboolean callbacks_try_to_select(guint Akey, GtkTreeView *Aliste, Tgrave *Ag);
extern gboolean callback_simpledialog_eventkeyrelease(GtkWidget *Aentry, GdkEventKey *Aevent, gpointer Adata);

#endif

/*
 * vim:et:ts=8:sts=2:sw=2
 */
